@@ -46,7 +46,7 @@ from .exceptions import (
     NabuCasaConnectionError,
 )
 from .files import Files, FilesError, StorageType, StoredFile, calculate_b64md5
-from .google_report_state import GoogleReportState
+from .google_report_state import GoogleReportState, GoogleReportStateError
 from .ice_servers import IceServers, IceServersApiError
 from .instance_api import InstanceApi, InstanceApiError, InstanceConnectionDetails
 from .iot import CloudIoT
@@ -78,6 +78,7 @@ __all__ = [
     "CloudClient",
     "CloudError",
     "FilesError",
+    "GoogleReportStateError",
     "IceServersApiError",
     "InstanceApiError",
     "InstanceConnectionDetails",
