@@ -1,16 +1,21 @@
 """Set up some common test helper things."""
 
 import asyncio
+from collections.abc import AsyncGenerator
 import logging
-from typing import cast
+from pathlib import Path
+from typing import Any, cast
 from unittest.mock import AsyncMock, MagicMock, PropertyMock, patch
 
 from aiohttp import web
 from freezegun import freeze_time
+import jwt
 import pytest
 
+import hass_nabucasa
+
 from .common import MockClient
-from .utils.aiohttp import mock_aiohttp_client
+from .utils.aiohttp import AiohttpClientMocker, mock_aiohttp_client
 
 logging.basicConfig(level=logging.DEBUG)
 
@@ -92,6 +97,90 @@ def cloud_client(cloud_mock: MagicMock) -> MockClient:
     return cast("MockClient", cloud_mock.client)
 
 
+@pytest.fixture
+async def cloud(
+    aioclient_mock: AiohttpClientMocker,
+    loop: asyncio.AbstractEventLoop,
+    tmp_path: Path,
+) -> AsyncGenerator[hass_nabucasa.Cloud, Any]:
+    """Create a cloud fixture."""
+    client_session = aioclient_mock.create_session(loop)
+    client = MockClient(tmp_path, loop, client_session)
+
+    cloud_dir = tmp_path / ".cloud"
+    cloud_dir.mkdir(exist_ok=True)
+
+    with (
+        patch("pathlib.Path.chmod"),
+        patch("pathlib.Path.read_text", return_value=""),
+        patch("pathlib.Path.write_bytes"),
+        patch("pathlib.Path.write_text"),
+        patch("shutil.rmtree"),
+    ):
+        cloud = hass_nabucasa.Cloud(
+            client,
+            "development",
+            cognito_client_id="abc123",
+            region="xx-earth-616",
+            account_link_server="account-link.example.com",
+            accounts_server="accounts.example.com",
+            cloudhook_server="cloudhooks.example.com",
+            acme_server="acme.example.com",
+            relayer_server="relayer.example.com",
+            remotestate_server="remotestate.example.com",
+            servicehandlers_server="servicehandlers.example.com",
+        )
+
+        fake_secret = "fake-test-secret"
+
+        id_token_claims = {
+            "cognito:username": "test@example.com",
+            "custom:sub-exp": "2019-09-17",
+            "iat": 1537185600,
+            "exp": 1537185600 + (365 * 24 * 60 * 60),
+            "token_use": "id",
+        }
+
+        access_token_claims = {
+            "client_id": "test-client-id",
+            "username": "test@example.com",
+            "token_use": "access",
+            "scope": "aws.cognito.signin.user.admin",
+            "iat": 1537185600,
+            "exp": 1537185600 + 3600,
+        }
+
+        refresh_token_claims = {
+            "client_id": "test-client-id",
+            "username": "test@example.com",
+            "token_use": "refresh",
+            "iat": 1537185600,
+            "exp": 1537185600 + (30 * 24 * 60 * 60),
+        }
+
+        id_token = jwt.encode(id_token_claims, fake_secret, algorithm="HS256")
+        access_token = jwt.encode(access_token_claims, fake_secret, algorithm="HS256")
+        refresh_token = jwt.encode(refresh_token_claims, fake_secret, algorithm="HS256")
+        renewed_id_token = jwt.encode(id_token_claims, fake_secret, algorithm="HS256")
+        renewed_access_token = jwt.encode(
+            access_token_claims, fake_secret, algorithm="HS256"
+        )
+
+        mock_cognito = MagicMock()
+        mock_cognito.id_token = renewed_id_token
+        mock_cognito.access_token = renewed_access_token
+        cloud.auth._create_cognito_client = MagicMock(return_value=mock_cognito)
+
+        cloud.auth.async_check_token = AsyncMock()
+
+        cloud.id_token = id_token
+        cloud.access_token = access_token
+        cloud.refresh_token = refresh_token
+
+        yield cloud
+        await client_session.close()
+
+
 @pytest.fixture
 def mock_cognito():
     """Mock warrant."""
